==> django-persistent-settings-0.1.3a2.tar.gz: django-persistent-settings-0.1.3a2/README.md <==
# Django Persistent Settings

[![PyPI - Version][version_badge_url]][pypi_url]
[![PyPI - Status][status_badge_url]][pypi_url]
[![PyPI - License][license_badge_url]](LICENSE.txt)
![PyPI - Python][python_badge_url]
![PyPI - Django][django_badge_url]
![Downloads - Month][dlmonth_badge_url]

<!-- Meta Links Start -->

[version_badge_url]: https://img.shields.io/pypi/v/django-persistent-settings?label=version&logoColor=white&style=flat-square
[status_badge_url]: https://img.shields.io/pypi/status/django-persistent-settings?style=flat-square
[license_badge_url]: https://img.shields.io/pypi/l/django-persistent-settings?style=flat-square
[python_badge_url]: https://img.shields.io/pypi/pyversions/django-persistent-settings?color=3572a2&label=%20&logo=python&logoColor=FECE3D&style=flat-square
[django_badge_url]: https://img.shields.io/pypi/djversions/django-persistent-settings?color=092e20&label=%20&logo=django&logoColor=white&style=flat-square
[dlmonth_badge_url]: https://img.shields.io/pypi/dm/django-persistent-settings?label=dl%2Fmonth&style=flat-square

[pypi_url]: https://pypi.org/project/django-persistent-settings/

<!-- Meta Links Start -->

Django Persistent Settings helps you store, retrieve and update platform specific settings in Django and provides many ways in setting retrieval such as request injection or template tags. It is inspired by Laravel's [akaunting/setting](https://github.com/akaunting/setting) package.

| | Build | Coverage |
|-|---|---|
| **master** | [![Linux - Master][linux_master_badge_url]][linux_master_url] | [![Coverage - Master][codecov_master_badge_url]][codecov_master_url] |
| **development** | [![Linux - Development][linux_development_badge_url]][linux_development_url] | [![Coverage - Development][codecov_development_badge_url]][codecov_development_url] |

<!-- Build Links Start -->

[linux_development_badge_url]: https://img.shields.io/github/workflow/status/erayerdin/django-persistent-settings/testing/development?logo=linux&logoColor=white&style=flat-square
[linux_master_badge_url]: https://img.shields.io/github/workflow/status/erayerdin/django-persistent-settings/testing/master?logo=linux&logoColor=white&style=flat-square

[codecov_development_badge_url]: https://img.shields.io/codecov/c/gh/erayerdin/django-persistent-settings/development?style=flat-square
[codecov_master_badge_url]: https://img.shields.io/codecov/c/gh/erayerdin/django-persistent-settings/master?style=flat-square

[linux_development_url]: https://github.com/erayerdin/django-persistent-settings/actions?query=workflow%3A%22Build+and+Distribute%22+branch%3Adevelopment
[linux_master_url]: https://github.com/erayerdin/django-persistent-settings/actions?query=workflow%3A%22Build+and+Distribute%22+branch%3Amaster

[codecov_development_url]: https://codecov.io/gh/erayerdin/django-persistent-settings/branch/development
[codecov_master_url]: https://codecov.io/gh/erayerdin/django-persistent-settings/branch/master

<!-- Build Links End -->

# Documentation

Please refer to [the documentation](https://django-persistent-settings.readthedocs.io/).

# License

Licensed under the terms of [Apache License 2.0](LICENSE.txt).

==> django-persistent-settings-0.1.4a1.tar.gz: django-persistent-settings-0.1.4a1/README.md <==
# Django Persistent Settings

[![PyPI - Version][version_badge_url]][pypi_url]
[![PyPI - Status][status_badge_url]][pypi_url]
[![PyPI - License][license_badge_url]](LICENSE.txt)
![PyPI - Python][python_badge_url]
![PyPI - Django][django_badge_url]
![Downloads - Month][dlmonth_badge_url]

<!-- Meta Links Start -->

[version_badge_url]: https://img.shields.io/pypi/v/django-persistent-settings?label=version&logoColor=white&style=flat-square
[status_badge_url]: https://img.shields.io/pypi/status/django-persistent-settings?style=flat-square
[license_badge_url]: https://img.shields.io/pypi/l/django-persistent-settings?style=flat-square
[python_badge_url]: https://img.shields.io/pypi/pyversions/django-persistent-settings?color=3572a2&label=%20&logo=python&logoColor=FECE3D&style=flat-square
[django_badge_url]: https://img.shields.io/pypi/djversions/django-persistent-settings?color=092e20&label=%20&logo=django&logoColor=white&style=flat-square
[dlmonth_badge_url]: https://img.shields.io/pypi/dm/django-persistent-settings?label=dl%2Fmonth&style=flat-square

[pypi_url]: https://pypi.org/project/django-persistent-settings/

<!-- Meta Links End -->

Django Persistent Settings helps you store, retrieve and update platform specific settings in Django and provides many ways in setting retrieval such as request injection or template tags. It is inspired by Laravel's [akaunting/setting](https://github.com/akaunting/setting) package.

| | Build | Coverage |
|-|---|---|
| **master** | [![Linux - Master][linux_master_badge_url]][linux_master_url] | [![Coverage - Master][codecov_master_badge_url]][codecov_master_url] |
| **development** | [![Linux - Development][linux_development_badge_url]][linux_development_url] | [![Coverage - Development][codecov_development_badge_url]][codecov_development_url] |

<!-- Build Links Start -->

[linux_development_badge_url]: https://img.shields.io/github/workflow/status/erayerdin/django-persistent-settings/testing/development?logo=linux&logoColor=white&style=flat-square
[linux_master_badge_url]: https://img.shields.io/github/workflow/status/erayerdin/django-persistent-settings/testing/master?logo=linux&logoColor=white&style=flat-square

[codecov_development_badge_url]: https://img.shields.io/codecov/c/gh/erayerdin/django-persistent-settings/development?style=flat-square
[codecov_master_badge_url]: https://img.shields.io/codecov/c/gh/erayerdin/django-persistent-settings/master?style=flat-square

[linux_development_url]: https://github.com/erayerdin/django-persistent-settings/actions?query=workflow%3A%22Build+and+Distribute%22+branch%3Adevelopment
[linux_master_url]: https://github.com/erayerdin/django-persistent-settings/actions?query=workflow%3A%22Build+and+Distribute%22+branch%3Amaster

[codecov_development_url]: https://codecov.io/gh/erayerdin/django-persistent-settings/branch/development
[codecov_master_url]: https://codecov.io/gh/erayerdin/django-persistent-settings/branch/master

<!-- Build Links End -->

# Documentation

Please refer to [the documentation](https://django-persistent-settings.readthedocs.io/)
to get information about how to utilize this library.

# License

Licensed under the terms of [Apache License 2.0](LICENSE.txt).
